## Pagination
Use Mastodon API to implement continuous toot scrolling

## Search mode
Implement a search mode similar to mastodon website

## Reporting system
Implement a way to report users with the proper Mastodon system

## Filtering system
Implement ability to filter posts

## More Tooting Options
Visibility control, polls, media attachments

## Settings in Control Panel
Important program settings should be accessible in control panel, synced
with the settings page

## More pages
Hashtag page / News page / Muted users / Blocked users / 
Muted words / Blocked domains / Followed Hashtags / Pending requests

## Authentication / Working over SSH
Program should be fully usable over SSH

## Better back button
Back button should save the scrollbar location on the previous pages.

## Open in-instance
Clicking links opens them from perspective of your logged-in instance

## Private mode
User login will not be saved to the database

## Save session to temp storage
System to store downloaded JSON data temporary database so the
user can close and re-open the program without re-downloading all the data.